// (C) 2001-2024 Intel Corporation. All rights reserved.
// Your use of Intel Corporation's design tools, logic functions and other 
// software and tools, and its AMPP partner logic functions, and any output 
// files from any of the foregoing (including device programming or simulation 
// files), and any associated documentation or information are expressly subject 
// to the terms and conditions of the Intel Program License Subscription 
// Agreement, Intel FPGA IP License Agreement, or other applicable 
// license agreement, including, without limitation, that your use is for the 
// sole purpose of programming logic devices manufactured by Intel and sold by 
// Intel or its authorized distributors.  Please refer to the applicable 
// agreement for further details.


`timescale 1ns / 100ps
module  bts_config (
        //Reset&Clock
        input  wire        cpu_resetn            , // Reset, low active
        input  wire        clk_sys_bak_50m_p     , // System clock, 50MHz
        input  wire        refclk_156m_qsfpdd_p  , // QSFPDD reference clock 156.25MHz
      //input  wire        refclk_pcie_ch0_p     , // PCIe reference clock 100MHz
        //I2C interfaces                         
        inout  wire        fpga_i2c_scl          , // FPGA regular I2C interface
        inout  wire        fpga_i2c_sda          , // FPGA regular I2C interface
        inout  wire        ddr4_dimm_scl         , // DDR4 I2C interface
        inout  wire        ddr4_dimm_sda         , // DDR4 I2C interface
        //GPIOs                                  
        output wire [3:0]  fm6_led               , // User LEDs, external pull-down
      //output wire        gpio_trig_out         , // GPIO trigger out, not available in EP version
      //input  wire        gpio_trig_in          , // GPIO trigger in, not available in EP version
        //QSFPDD LEDs
        output wire [2:0]  qsfpdd0_fm6_led       , // QSFPDD0 LEDs, external pull-down
        output wire [2:0]  qsfpdd1_fm6_led       , // QSFPDD1 LEDs, external pull-down
        //QSFPDD control signals
        inout  wire        qsfpdd_fm6_i2c_scl    , // QSFPDD control
        inout  wire        qsfpdd_fm6_i2c_sda    , // QSFPDD control
        input  wire        qsfpdd0_1v2_int_l     , // QSFPDD control
        input  wire        qsfpdd0_1v2_modprs_l  , // QSFPDD control
        output wire        qsfpdd0_1v2_reset_l   , // QSFPDD control, external pull-up
        output wire        qsfpdd0_1v2_modsel_l  , // QSFPDD control, external pull-up
        output wire        qsfpdd0_1v2_lpmode    , // QSFPDD control
        input  wire        qsfpdd1_1v2_int_l     , // QSFPDD control
        input  wire        qsfpdd1_1v2_modprs_l  , // QSFPDD control
        output wire        qsfpdd1_1v2_reset_l   , // QSFPDD control, external pull-up
        output wire        qsfpdd1_1v2_modsel_l  , // QSFPDD control, external pull-up
        output wire        qsfpdd1_1v2_lpmode      // QSFPDD control
        );
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//Signal definitions
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
wire          ninit_done;
wire          global_resetn/* synthesis keep */;
wire          fpga_i2c_scl_in;
wire          fpga_i2c_sda_in;
wire          fpga_i2c_scl_oe;
wire          fpga_i2c_sda_oe;
wire          ddr4_dimm_scl_in;
wire          ddr4_dimm_sda_in;
wire          ddr4_dimm_scl_oe;
wire          ddr4_dimm_sda_oe;
wire          qsfpdd_fm6_i2c_scl_in;
wire          qsfpdd_fm6_i2c_sda_in;
wire          qsfpdd_fm6_i2c_scl_oe;
wire          qsfpdd_fm6_i2c_sda_oe;
wire          qsfpdd_modsel_ctrl;
wire   [1:0]  qsfpdd_reset_ctrl;
wire   [1:0]  qsfpdd_lpmode_ctrl;
wire   [5:0]  qsfpdd_led_ctrl;
wire   [3:0]  qsfpdd_int_prs_ctrl;
wire   [3:0]  gpio_led_ctrl;
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//Input/output assignments
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
assign fpga_i2c_scl_in       = fpga_i2c_scl;
assign fpga_i2c_sda_in       = fpga_i2c_sda;
assign fpga_i2c_scl          = fpga_i2c_scl_oe ? 1'b0 : 1'bz;
assign fpga_i2c_sda          = fpga_i2c_sda_oe ? 1'b0 : 1'bz;
assign ddr4_dimm_scl_in      = ddr4_dimm_scl;
assign ddr4_dimm_sda_in      = ddr4_dimm_sda;
assign ddr4_dimm_scl         = ddr4_dimm_scl_oe ? 1'b0 : 1'bz;
assign ddr4_dimm_sda         = ddr4_dimm_sda_oe ? 1'b0 : 1'bz;
assign qsfpdd_fm6_i2c_scl_in = qsfpdd_fm6_i2c_scl;
assign qsfpdd_fm6_i2c_sda_in = qsfpdd_fm6_i2c_sda;
assign qsfpdd_fm6_i2c_scl    = qsfpdd_fm6_i2c_scl_oe ? 1'b0 : 1'bz;
assign qsfpdd_fm6_i2c_sda    = qsfpdd_fm6_i2c_sda_oe ? 1'b0 : 1'bz;
//----------------------------------------------------------------------------------------------------------
// Intel Agilex Reset Release
//----------------------------------------------------------------------------------------------------------
reset_release reset_release_inst 
              (
              .ninit_done (ninit_done)  // ninit_done.ninit_done, low active
              );
assign global_resetn = !ninit_done & cpu_resetn;
//assign global_resetn = cpu_resetn;
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//Qsys module
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
q_sys   q_sys_inst0 (
        .clk_50_clk                       (clk_sys_bak_50m_p     ), //                    clk_50.clk
        .reset_50_reset_n                 (global_resetn         ), //                  reset_50.reset_n
        .i2c_0_i2c_serial_sda_in          (fpga_i2c_sda_in       ), //          i2c_0_i2c_serial.sda_in
        .i2c_0_i2c_serial_scl_in          (fpga_i2c_scl_in       ), //                          .scl_in
        .i2c_0_i2c_serial_sda_oe          (fpga_i2c_sda_oe       ), //                          .sda_oe
        .i2c_0_i2c_serial_scl_oe          (fpga_i2c_scl_oe       ), //                          .scl_oe
        .i2c_1_i2c_serial_sda_in          (ddr4_dimm_sda_in      ), //          i2c_1_i2c_serial.sda_in
        .i2c_1_i2c_serial_scl_in          (ddr4_dimm_scl_in      ), //                          .scl_in
        .i2c_1_i2c_serial_sda_oe          (ddr4_dimm_sda_oe      ), //                          .sda_oe
        .i2c_1_i2c_serial_scl_oe          (ddr4_dimm_scl_oe      ), //                          .scl_oe
        .i2c_2_i2c_serial_sda_in          (qsfpdd_fm6_i2c_sda_in ), //          i2c_2_i2c_serial.sda_in
        .i2c_2_i2c_serial_scl_in          (qsfpdd_fm6_i2c_scl_in ), //                          .scl_in
        .i2c_2_i2c_serial_sda_oe          (qsfpdd_fm6_i2c_sda_oe ), //                          .sda_oe
        .i2c_2_i2c_serial_scl_oe          (qsfpdd_fm6_i2c_scl_oe ), //                          .scl_oe
        .pio_0_qsfpdd_modsel_export       (qsfpdd_modsel_ctrl    ), //       pio_0_qsfpdd_modsel.export
        .pio_1_qsfpdd_reset_export        (qsfpdd_reset_ctrl     ), //        pio_1_qsfpdd_reset.export
        .pio_2_qsfpdd_lpmode_export       (qsfpdd_lpmode_ctrl    ), //       pio_2_qsfpdd_lpmode.export
        .pio_3_qsfpdd_led_export          (qsfpdd_led_ctrl       ), //          pio_3_qsfpdd_led.export
        .pio_4_qsfpdd_int_prs_export      (qsfpdd_int_prs_ctrl   ), //      pio_4_qsfpdd_int_prs.export
        .pio_5_gpio_led_export            (gpio_led_ctrl         )  //            pio_5_gpio_led.export
        );
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//Input/output assignments
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
assign qsfpdd_int_prs_ctrl = {qsfpdd1_1v2_modprs_l, qsfpdd0_1v2_modprs_l, 
                              qsfpdd1_1v2_int_l,    qsfpdd0_1v2_int_l}; // QSFPDD interrupts and presence signals
assign qsfpdd0_1v2_reset_l  = qsfpdd_reset_ctrl[0]  ? 1'bz : 1'b0; // qsfpdd_reset_ctrl[0]: 1'b1 by default
assign qsfpdd0_1v2_modsel_l = qsfpdd_modsel_ctrl    ? 1'bz : 1'b0; // qsfpdd_modsel_ctrl: 1'b0 by default
assign qsfpdd0_1v2_lpmode   = qsfpdd_lpmode_ctrl[0] ? 1'b1 : 1'b0; // qsfpdd_lpmode_ctrl[0]: 1'b0 by default
assign qsfpdd1_1v2_reset_l  = qsfpdd_reset_ctrl[1]  ? 1'bz : 1'b0; // qsfpdd_reset_ctrl[1]: 1'b1 by default
assign qsfpdd1_1v2_modsel_l = qsfpdd_modsel_ctrl    ? 1'b0 : 1'bz; // qsfpdd_modsel_ctrl: 1'b0 by default
assign qsfpdd1_1v2_lpmode   = qsfpdd_lpmode_ctrl[1] ? 1'b1 : 1'b0; // qsfpdd_lpmode_ctrl[1]: 1'b0 by default
assign qsfpdd0_fm6_led[0]   = qsfpdd_led_ctrl[0]    ? 1'b1 : 1'b0; // qsfpdd_led_ctrl[0]: 1'b0 by default
assign qsfpdd0_fm6_led[1]   = qsfpdd_led_ctrl[1]    ? 1'b1 : 1'b0; // qsfpdd_led_ctrl[1]: 1'b0 by default
assign qsfpdd0_fm6_led[2]   = qsfpdd_led_ctrl[2]    ? 1'b1 : 1'b0; // qsfpdd_led_ctrl[2]: 1'b0 by default
assign qsfpdd1_fm6_led[0]   = qsfpdd_led_ctrl[3]    ? 1'b1 : 1'b0; // qsfpdd_led_ctrl[3]: 1'b0 by default
assign qsfpdd1_fm6_led[1]   = qsfpdd_led_ctrl[4]    ? 1'b1 : 1'b0; // qsfpdd_led_ctrl[4]: 1'b0 by default
assign qsfpdd1_fm6_led[2]   = qsfpdd_led_ctrl[5]    ? 1'b1 : 1'b0; // qsfpdd_led_ctrl[5]: 1'b0 by default
assign fm6_led[0]           = gpio_led_ctrl[0]      ? 1'b1 : 1'b0; // gpio_led_ctrl[0]: 1'b0 by default
assign fm6_led[1]           = gpio_led_ctrl[1]      ? 1'b1 : 1'b0; // gpio_led_ctrl[0]: 1'b0 by default
assign fm6_led[2]           = gpio_led_ctrl[2]      ? 1'b1 : 1'b0; // gpio_led_ctrl[0]: 1'b0 by default
assign fm6_led[3]           = gpio_led_ctrl[3]      ? 1'b1 : 1'b0; // gpio_led_ctrl[0]: 1'b0 by default
endmodule
	
