`timescale 1ns / 100ps
module  golden_top (
        //Reset&Clock
        input  wire        cpu_resetn            , // Reset, low active
        input  wire        clk_sys_100m_p        , // System clock, 100MHz
        input  wire        clk_sys_bak_50m_p     , // System clock, 50MHz

        //I2C interfaces                         
        inout  wire        fpga_i2c_scl          , // FPGA regular I2C interface
        inout  wire        fpga_i2c_sda          , // FPGA regular I2C interface
        inout  wire        ddr4_dimm_scl         , // DDR4 I2C interface
        inout  wire        ddr4_dimm_sda         , // DDR4 I2C interface

        //GPIOs                                  
        output wire [3:0]  fm6_led               , // User LEDs, external pull-down
        //output wire      gpio_trig_out         , // GPIO trigger out, not available in EP version
        //input  wire      gpio_trig_in          , // GPIO trigger in, not available in EP version

        //EMIF interface #0
        input  wire        clk_ddr4_ch0_p        , // ddr_ref_clk.clk
        output wire [1:0]  ddr4_dimm_ch0_ck_p    , //         mem.mem_ck
        output wire [1:0]  ddr4_dimm_ch0_ck_n    , //            .mem_ck_n
        output wire [17:0] ddr4_dimm_ch0_a       , //            .mem_a
        output wire        ddr4_dimm_ch0_act_n   , //            .mem_act_n
        output wire [1:0]  ddr4_dimm_ch0_ba      , //            .mem_ba
        output wire [1:0]  ddr4_dimm_ch0_bg      , //            .mem_bg
        output wire [1:0]  ddr4_dimm_ch0_cke     , //            .mem_cke
        output wire [3:0]  ddr4_dimm_ch0_cs_n    , //            .mem_cs_n
        output wire [1:0]  ddr4_dimm_ch0_odt     , //            .mem_odt
        output wire        ddr4_dimm_ch0_reset_n , //            .mem_reset_n
        output wire        ddr4_dimm_ch0_par     , //            .mem_par
        input  wire        ddr4_dimm_ch0_alert_n , //            .mem_alert_n
        inout  wire [8:0]  ddr4_dimm_ch0_dqs_p   , //            .mem_dqs
        inout  wire [8:0]  ddr4_dimm_ch0_dqs_n   , //            .mem_dqs_n
        inout  wire [8:0]  ddr4_dimm_ch0_dbi_n   , //            .mem_dqs
        inout  wire [17:9] ddr4_dimm_ch0_tdqs_n  , //            .mem_tdqs_n
        inout  wire        ddr4_ch0_save_n       , //            .mem_save_n
        inout  wire        ddr4_ch0_event_n      , //            .mem_event_n
        inout  wire        ddr4_dimm_ch0_c2      , //            .unused
        inout  wire [71:0] ddr4_dimm_ch0_dq      , //            .mem_dq
        input  wire        ddr4_dimm_ch0_rzq     , //            .oct_rzqin

        //EMIF interface #2
        input  wire        clk_ddr4_ch2_p        , // ddr_ref_clk.clk
        output wire [1:0]  ddr4_dimm_ch2_ck_p    , //         mem.mem_ck
        output wire [1:0]  ddr4_dimm_ch2_ck_n    , //            .mem_ck_n
        output wire [17:0] ddr4_dimm_ch2_a       , //            .mem_a
        output wire        ddr4_dimm_ch2_act_n   , //            .mem_act_n
        output wire [1:0]  ddr4_dimm_ch2_ba      , //            .mem_ba
        output wire [1:0]  ddr4_dimm_ch2_bg      , //            .mem_bg
        output wire [1:0]  ddr4_dimm_ch2_cke     , //            .mem_cke
        output wire [3:0]  ddr4_dimm_ch2_cs_n    , //            .mem_cs_n
        output wire [1:0]  ddr4_dimm_ch2_odt     , //            .mem_odt
        output wire        ddr4_dimm_ch2_reset_n , //            .mem_reset_n
        output wire        ddr4_dimm_ch2_par     , //            .mem_par
        input  wire        ddr4_dimm_ch2_alert_n , //            .mem_alert_n
        inout  wire [8:0]  ddr4_dimm_ch2_dqs_p   , //            .mem_dqs
        inout  wire [8:0]  ddr4_dimm_ch2_dqs_n   , //            .mem_dqs_n
        inout  wire [8:0]  ddr4_dimm_ch2_dbi_n   , //            .mem_dqs
        inout  wire [17:9] ddr4_dimm_ch2_tdqs_n  , //            .mem_tdqs_n
        inout  wire        ddr4_ch2_save_n       , //            .mem_save_n
        inout  wire        ddr4_ch2_event_n      , //            .mem_event_n
        inout  wire        ddr4_dimm_ch2_c2      , //            .unused
        inout  wire [71:0] ddr4_dimm_ch2_dq      , //            .mem_dq
        input  wire        ddr4_dimm_ch2_rzq     , //            .oct_rzqin

        //EMIF interface #3
        input  wire        clk_ddr4_ch3_p        , // ddr_ref_clk.clk
        output wire [1:0]  ddr4_dimm_ch3_ck_p    , //         mem.mem_ck
        output wire [1:0]  ddr4_dimm_ch3_ck_n    , //            .mem_ck_n
        output wire [17:0] ddr4_dimm_ch3_a       , //            .mem_a
        output wire        ddr4_dimm_ch3_act_n   , //            .mem_act_n
        output wire [1:0]  ddr4_dimm_ch3_ba      , //            .mem_ba
        output wire [1:0]  ddr4_dimm_ch3_bg      , //            .mem_bg
        output wire [1:0]  ddr4_dimm_ch3_cke     , //            .mem_cke
        output wire [3:0]  ddr4_dimm_ch3_cs_n    , //            .mem_cs_n
        output wire [1:0]  ddr4_dimm_ch3_odt     , //            .mem_odt
        output wire        ddr4_dimm_ch3_reset_n , //            .mem_reset_n
        output wire        ddr4_dimm_ch3_par     , //            .mem_par
        input  wire        ddr4_dimm_ch3_alert_n , //            .mem_alert_n
        inout  wire [8:0]  ddr4_dimm_ch3_dqs_p   , //            .mem_dqs
        inout  wire [8:0]  ddr4_dimm_ch3_dqs_n   , //            .mem_dqs_n
        inout  wire [8:0]  ddr4_dimm_ch3_dbi_n   , //            .mem_dqs
        inout  wire [17:9] ddr4_dimm_ch3_tdqs_n  , //            .mem_tdqs_n
        inout  wire        ddr4_ch3_save_n       , //            .mem_save_n
        inout  wire        ddr4_ch3_event_n      , //            .mem_event_n
        inout  wire [71:0] ddr4_dimm_ch3_dq      , //            .mem_dq
        input  wire        ddr4_dimm_ch3_rzq     , //            .oct_rzqin

        //PCIe 4.0 Genx16
        input  wire        fm6_pcie_perstn       , // PCIe Gen4 Endpoint interface
        input  wire        refclk_pcie_ch0_p     , // PCIe Gen4 Endpoint interface
        input  wire        refclk_pcie_ch2_p     , // PCIe Gen4 Endpoint interface
        input  wire        pcie_ep_rx_p0         , // PCIe Gen4 Endpoint interface
        input  wire        pcie_ep_rx_n0         , // PCIe Gen4 Endpoint interface
        input  wire        pcie_ep_rx_p1         , // PCIe Gen4 Endpoint interface
        input  wire        pcie_ep_rx_n1         , // PCIe Gen4 Endpoint interface
        input  wire        pcie_ep_rx_p2         , // PCIe Gen4 Endpoint interface
        input  wire        pcie_ep_rx_n2         , // PCIe Gen4 Endpoint interface
        input  wire        pcie_ep_rx_p3         , // PCIe Gen4 Endpoint interface
        input  wire        pcie_ep_rx_n3         , // PCIe Gen4 Endpoint interface
        input  wire        pcie_ep_rx_p4         , // PCIe Gen4 Endpoint interface
        input  wire        pcie_ep_rx_n4         , // PCIe Gen4 Endpoint interface
        input  wire        pcie_ep_rx_p5         , // PCIe Gen4 Endpoint interface
        input  wire        pcie_ep_rx_n5         , // PCIe Gen4 Endpoint interface
        input  wire        pcie_ep_rx_p6         , // PCIe Gen4 Endpoint interface
        input  wire        pcie_ep_rx_n6         , // PCIe Gen4 Endpoint interface
        input  wire        pcie_ep_rx_p7         , // PCIe Gen4 Endpoint interface
        input  wire        pcie_ep_rx_n7         , // PCIe Gen4 Endpoint interface
        input  wire        pcie_ep_rx_p8         , // PCIe Gen4 Endpoint interface
        input  wire        pcie_ep_rx_n8         , // PCIe Gen4 Endpoint interface
        input  wire        pcie_ep_rx_p9         , // PCIe Gen4 Endpoint interface
        input  wire        pcie_ep_rx_n9         , // PCIe Gen4 Endpoint interface
        input  wire        pcie_ep_rx_p10        , // PCIe Gen4 Endpoint interface
        input  wire        pcie_ep_rx_n10        , // PCIe Gen4 Endpoint interface
        input  wire        pcie_ep_rx_p11        , // PCIe Gen4 Endpoint interface
        input  wire        pcie_ep_rx_n11        , // PCIe Gen4 Endpoint interface
        input  wire        pcie_ep_rx_p12        , // PCIe Gen4 Endpoint interface
        input  wire        pcie_ep_rx_n12        , // PCIe Gen4 Endpoint interface
        input  wire        pcie_ep_rx_p13        , // PCIe Gen4 Endpoint interface
        input  wire        pcie_ep_rx_n13        , // PCIe Gen4 Endpoint interface
        input  wire        pcie_ep_rx_p14        , // PCIe Gen4 Endpoint interface
        input  wire        pcie_ep_rx_n14        , // PCIe Gen4 Endpoint interface
        input  wire        pcie_ep_rx_p15        , // PCIe Gen4 Endpoint interface
        input  wire        pcie_ep_rx_n15        , // PCIe Gen4 Endpoint interface
        output wire        pcie_ep_tx_p0         , // PCIe Gen4 Endpoint interface
        output wire        pcie_ep_tx_n0         , // PCIe Gen4 Endpoint interface
        output wire        pcie_ep_tx_p1         , // PCIe Gen4 Endpoint interface
        output wire        pcie_ep_tx_n1         , // PCIe Gen4 Endpoint interface
        output wire        pcie_ep_tx_p2         , // PCIe Gen4 Endpoint interface
        output wire        pcie_ep_tx_n2         , // PCIe Gen4 Endpoint interface
        output wire        pcie_ep_tx_p3         , // PCIe Gen4 Endpoint interface
        output wire        pcie_ep_tx_n3         , // PCIe Gen4 Endpoint interface
        output wire        pcie_ep_tx_p4         , // PCIe Gen4 Endpoint interface
        output wire        pcie_ep_tx_n4         , // PCIe Gen4 Endpoint interface
        output wire        pcie_ep_tx_p5         , // PCIe Gen4 Endpoint interface
        output wire        pcie_ep_tx_n5         , // PCIe Gen4 Endpoint interface
        output wire        pcie_ep_tx_p6         , // PCIe Gen4 Endpoint interface
        output wire        pcie_ep_tx_n6         , // PCIe Gen4 Endpoint interface
        output wire        pcie_ep_tx_p7         , // PCIe Gen4 Endpoint interface
        output wire        pcie_ep_tx_n7         , // PCIe Gen4 Endpoint interface
        output wire        pcie_ep_tx_p8         , // PCIe Gen4 Endpoint interface
        output wire        pcie_ep_tx_n8         , // PCIe Gen4 Endpoint interface
        output wire        pcie_ep_tx_p9         , // PCIe Gen4 Endpoint interface
        output wire        pcie_ep_tx_n9         , // PCIe Gen4 Endpoint interface
        output wire        pcie_ep_tx_p10        , // PCIe Gen4 Endpoint interface
        output wire        pcie_ep_tx_n10        , // PCIe Gen4 Endpoint interface
        output wire        pcie_ep_tx_p11        , // PCIe Gen4 Endpoint interface
        output wire        pcie_ep_tx_n11        , // PCIe Gen4 Endpoint interface
        output wire        pcie_ep_tx_p12        , // PCIe Gen4 Endpoint interface
        output wire        pcie_ep_tx_n12        , // PCIe Gen4 Endpoint interface
        output wire        pcie_ep_tx_p13        , // PCIe Gen4 Endpoint interface
        output wire        pcie_ep_tx_n13        , // PCIe Gen4 Endpoint interface
        output wire        pcie_ep_tx_p14        , // PCIe Gen4 Endpoint interface
        output wire        pcie_ep_tx_n14        , // PCIe Gen4 Endpoint interface
        output wire        pcie_ep_tx_p15        , // PCIe Gen4 Endpoint interface
        output wire        pcie_ep_tx_n15        , // PCIe Gen4 Endpoint interface

        //QSFPDD XCVR channels
        input  wire        refclk_322m_qsfpdd_p  , // QSFPDD reference clock 322MHz
        input  wire        refclk_156m_qsfpdd_p  , // QSFPDD reference clock 156MHz
        input  wire [7:0]  qsfpdd0_rx_p          , // QSFPDD #0 RX P
        input  wire [7:0]  qsfpdd0_rx_n          , // QSFPDD #0 RX N
        output wire [7:0]  qsfpdd0_tx_p          , // QSFPDD #0 TX P
        output wire [7:0]  qsfpdd0_tx_n          , // QSFPDD #0 TX N
        input  wire [7:0]  qsfpdd1_rx_p          , // QSFPDD #1 RX P
        input  wire [7:0]  qsfpdd1_rx_n          , // QSFPDD #1 RX N
        output wire [7:0]  qsfpdd1_tx_p          , // QSFPDD #1 TX P
        output wire [7:0]  qsfpdd1_tx_n          , // QSFPDD #1 TX N

        //QSFPDD LEDs
        output wire [2:0]  qsfpdd0_fm6_led       , // QSFPDD0 LEDs, external pull-down
        output wire [2:0]  qsfpdd1_fm6_led       , // QSFPDD1 LEDs, external pull-down

        //QSFPDD control signals
        inout  wire        qsfpdd_fm6_i2c_scl    , // QSFPDD control
        inout  wire        qsfpdd_fm6_i2c_sda    , // QSFPDD control
        input  wire        qsfpdd0_1v2_int_l     , // QSFPDD control
        input  wire        qsfpdd0_1v2_modprs_l  , // QSFPDD control
        output wire        qsfpdd0_1v2_reset_l   , // QSFPDD control, external pull-up
        output wire        qsfpdd0_1v2_modsel_l  , // QSFPDD control, external pull-up
        output wire        qsfpdd0_1v2_lpmode    , // QSFPDD control
        input  wire        qsfpdd1_1v2_int_l     , // QSFPDD control
        input  wire        qsfpdd1_1v2_modprs_l  , // QSFPDD control
        output wire        qsfpdd1_1v2_reset_l   , // QSFPDD control, external pull-up
        output wire        qsfpdd1_1v2_modsel_l  , // QSFPDD control, external pull-up
        output wire        qsfpdd1_1v2_lpmode    , // QSFPDD control

        //HPS EMIF interface
        input  wire        clk_ddr4_ch1_p        , // ddr_ref_clk.clk
        output wire        ddr4_dimm_ch1_ck_p0   , //         mem.mem_ck
        output wire        ddr4_dimm_ch1_ck_n0   , //            .mem_ck_n
        output wire [16:0] ddr4_dimm_ch1_a       , //            .mem_a
        output wire        ddr4_dimm_ch1_act_n   , //            .mem_act_n
        output wire [1:0]  ddr4_dimm_ch1_ba      , //            .mem_ba
        output wire [1:0]  ddr4_dimm_ch1_bg      , //            .mem_bg
        output wire [1:0]  ddr4_dimm_ch1_cke     , //            .mem_cke
        output wire [1:0]  ddr4_dimm_ch1_cs_n    , //            .mem_cs_n
        output wire [1:0]  ddr4_dimm_ch1_odt     , //            .mem_odt
        output wire        ddr4_dimm_ch1_reset_n , //            .mem_reset_n
        output wire        ddr4_dimm_ch1_par     , //            .mem_par
        input  wire        ddr4_dimm_ch1_alert_n , //            .mem_alert_n
        inout  wire [8:0]  ddr4_dimm_ch1_dqs_p   , //            .mem_dqs
        inout  wire [8:0]  ddr4_dimm_ch1_dqs_n   , //            .mem_dqs_n
        inout  wire [8:0]  ddr4_dimm_ch1_dbi_n   , //            .mem_dqs
        inout  wire [17:9] ddr4_dimm_ch1_tdqs_n  , //            .mem_dqs_n
        inout  wire        ddr4_ch1_save_n       , //            .mem_save_n
        inout  wire        ddr4_ch1_event_n      , //            .mem_event_n
        inout  wire [71:0] ddr4_dimm_ch1_dq      , //            .mem_dq
        input  wire        ddr4_dimm_ch1_rzq     , //            .oct_rzqin

        //HPS Peripherals
        input  wire        hps_osc_clk           , // HPS peripheral interfaces
        output wire        emmc_clk              , // HPS peripheral interfaces
        inout  wire        emmc_cmd              , // HPS peripheral interfaces
        inout  wire [7:0]  emmc_data             , // HPS peripheral interfaces
        output wire        enet_gtx_clk          , // HPS peripheral interfaces
        input  wire        enet_rx_clk           , // HPS peripheral interfaces
        output wire [3:0]  enet_txd              , // HPS peripheral interfaces
        input  wire [3:0]  enet_rxd              , // HPS peripheral interfaces
        output wire        enet_tx_en            , // HPS peripheral interfaces
        input  wire        enet_rx_dv            , // HPS peripheral interfaces
        inout  wire        enet_intn             , // HPS peripheral interfaces
        inout  wire        enet_mdio             , // HPS peripheral interfaces
        inout  wire        enet_mdc              , // HPS peripheral interfaces
        output wire        uart_tx               , // HPS peripheral interfaces
        input  wire        uart_rx               , // HPS peripheral interfaces
        input  wire        hps_i2c_sda           , // HPS peripheral interfaces
        input  wire        hps_i2c_scl           , // HPS peripheral interfaces
        input  wire        mictor_jtag_tck       , // HPS peripheral interfaces
        input  wire        mictor_jtag_tms       , // HPS peripheral interfaces
        output wire        mictor_jtag_tdo       , // HPS peripheral interfaces
        input  wire        mictor_jtag_tdi       , // HPS peripheral interfaces
        inout  wire        sd_cmd                , // HPS peripheral interfaces
        inout  wire        sd_clk                , // HPS peripheral interfaces
        inout  wire [3:0]  sd_data               , // HPS peripheral interfaces
        inout  wire        rsv_sd_resetn           // HPS peripheral interfaces
        );

endmodule


	