// (C) 2001-2024 Intel Corporation. All rights reserved.
// Your use of Intel Corporation's design tools, logic functions and other 
// software and tools, and its AMPP partner logic functions, and any output 
// files from any of the foregoing (including device programming or simulation 
// files), and any associated documentation or information are expressly subject 
// to the terms and conditions of the Intel Program License Subscription 
// Agreement, Intel FPGA IP License Agreement, or other applicable 
// license agreement, including, without limitation, that your use is for the 
// sole purpose of programming logic devices manufactured by Intel and sold by 
// Intel or its authorized distributors.  Please refer to the applicable 
// agreement for further details.


`timescale 1ns / 100ps
module  pcie_ep (
        //Reset&Clock
        input  wire        cpu_resetn                   , // Reset, low active
        input  wire        clk_sys_bak_50m_p            , // System clock, 50MHz
        input  wire        refclk_156m_qsfpdd_p         , // QSFPDD reference clock 156.25MHz
        //I2C interfaces                         
        inout  wire        fpga_i2c_scl                 , // FPGA regular I2C interface
        inout  wire        fpga_i2c_sda                 , // FPGA regular I2C interface
        inout  wire        ddr4_dimm_scl                , // DDR4 I2C interface
        inout  wire        ddr4_dimm_sda                , // DDR4 I2C interface
        //GPIOs                                  
        output wire [3:0]  fm6_led                      , // User LEDs
        //PCIe 4.0 Genx16
        input  wire        fm6_pcie_perstn              , // 
        input  wire        refclk_pcie_ch0_p            , // 
        input  wire        refclk_pcie_ch2_p            , // 
        input  wire        pcie_ep_rx_p0                , // 
        input  wire        pcie_ep_rx_n0                , // 
        input  wire        pcie_ep_rx_p1                , // 
        input  wire        pcie_ep_rx_n1                , // 
        input  wire        pcie_ep_rx_p2                , // 
        input  wire        pcie_ep_rx_n2                , // 
        input  wire        pcie_ep_rx_p3                , // 
        input  wire        pcie_ep_rx_n3                , // 
        input  wire        pcie_ep_rx_p4                , // 
        input  wire        pcie_ep_rx_n4                , // 
        input  wire        pcie_ep_rx_p5                , // 
        input  wire        pcie_ep_rx_n5                , // 
        input  wire        pcie_ep_rx_p6                , // 
        input  wire        pcie_ep_rx_n6                , // 
        input  wire        pcie_ep_rx_p7                , // 
        input  wire        pcie_ep_rx_n7                , // 
        input  wire        pcie_ep_rx_p8                , // 
        input  wire        pcie_ep_rx_n8                , // 
        input  wire        pcie_ep_rx_p9                , // 
        input  wire        pcie_ep_rx_n9                , // 
        input  wire        pcie_ep_rx_p10               , // 
        input  wire        pcie_ep_rx_n10               , // 
        input  wire        pcie_ep_rx_p11               , // 
        input  wire        pcie_ep_rx_n11               , // 
        input  wire        pcie_ep_rx_p12               , // 
        input  wire        pcie_ep_rx_n12               , // 
        input  wire        pcie_ep_rx_p13               , // 
        input  wire        pcie_ep_rx_n13               , // 
        input  wire        pcie_ep_rx_p14               , // 
        input  wire        pcie_ep_rx_n14               , // 
        input  wire        pcie_ep_rx_p15               , // 
        input  wire        pcie_ep_rx_n15               , // 
        output wire        pcie_ep_tx_p0                , // 
        output wire        pcie_ep_tx_n0                , // 
        output wire        pcie_ep_tx_p1                , // 
        output wire        pcie_ep_tx_n1                , // 
        output wire        pcie_ep_tx_p2                , // 
        output wire        pcie_ep_tx_n2                , // 
        output wire        pcie_ep_tx_p3                , // 
        output wire        pcie_ep_tx_n3                , // 
        output wire        pcie_ep_tx_p4                , // 
        output wire        pcie_ep_tx_n4                , // 
        output wire        pcie_ep_tx_p5                , // 
        output wire        pcie_ep_tx_n5                , // 
        output wire        pcie_ep_tx_p6                , // 
        output wire        pcie_ep_tx_n6                , // 
        output wire        pcie_ep_tx_p7                , // 
        output wire        pcie_ep_tx_n7                , // 
        output wire        pcie_ep_tx_p8                , // 
        output wire        pcie_ep_tx_n8                , // 
        output wire        pcie_ep_tx_p9                , // 
        output wire        pcie_ep_tx_n9                , // 
        output wire        pcie_ep_tx_p10               , // 
        output wire        pcie_ep_tx_n10               , // 
        output wire        pcie_ep_tx_p11               , // 
        output wire        pcie_ep_tx_n11               , // 
        output wire        pcie_ep_tx_p12               , // 
        output wire        pcie_ep_tx_n12               , // 
        output wire        pcie_ep_tx_p13               , // 
        output wire        pcie_ep_tx_n13               , // 
        output wire        pcie_ep_tx_p14               , // 
        output wire        pcie_ep_tx_n14               , // 
        output wire        pcie_ep_tx_p15               , // 
        output wire        pcie_ep_tx_n15                 // 
        );
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//Signal definitions
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
wire          ninit_done;
wire          global_resetn/* synthesis keep */;
reg  [26:0]   heart_beat_cnt;
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//Input/output assignments
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
assign fpga_i2c_scl  = 1'bz;
assign fpga_i2c_sda  = 1'bz;
assign ddr4_dimm_scl = 1'bz;
assign ddr4_dimm_sda = 1'bz;
assign fm6_led[3:0]  = {heart_beat_cnt[26], heart_beat_cnt[26], heart_beat_cnt[26],heart_beat_cnt[26]};
//----------------------------------------------------------------------------------------------------------
// Intel Agilex Reset Release
//----------------------------------------------------------------------------------------------------------
reset_release reset_release_inst 
              (
              .ninit_done (ninit_done)  // ninit_done.ninit_done
              );
assign global_resetn = !ninit_done & cpu_resetn;
//assign global_resetn = cpu_resetn;
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//Heart-beat indicate
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
always @(posedge clk_sys_bak_50m_p or negedge global_resetn)
    if (!global_resetn)
        heart_beat_cnt <= 27'h0; //0x7FFFFFF
    else
        heart_beat_cnt <= heart_beat_cnt + 1'b1;
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//Example design
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
pcie_ed     pcie_ed_inst0
            (
            .refclk0_clk                  (refclk_pcie_ch0_p), //    refclk0.clk
            .refclk1_clk                (refclk_pcie_ch2_p), //    refclk1.clk
            .pin_perst_pin_perst        (fm6_pcie_perstn  ), //  pin_perst.pin_perst
            .hip_serial_rx_n_in0          (pcie_ep_rx_n0    ), // hip_serial.rx_n_in0
            .hip_serial_rx_n_in1          (pcie_ep_rx_n1    ), //           .rx_n_in1
            .hip_serial_rx_n_in2          (pcie_ep_rx_n2    ), //           .rx_n_in2
            .hip_serial_rx_n_in3          (pcie_ep_rx_n3    ), //           .rx_n_in3
            .hip_serial_rx_n_in4          (pcie_ep_rx_n4    ), //           .rx_n_in4
            .hip_serial_rx_n_in5          (pcie_ep_rx_n5    ), //           .rx_n_in5
            .hip_serial_rx_n_in6          (pcie_ep_rx_n6    ), //           .rx_n_in6
            .hip_serial_rx_n_in7          (pcie_ep_rx_n7    ), //           .rx_n_in7
            .hip_serial_rx_n_in8          (pcie_ep_rx_n8    ), //           .rx_n_in8
            .hip_serial_rx_n_in9          (pcie_ep_rx_n9    ), //           .rx_n_in9
            .hip_serial_rx_n_in10         (pcie_ep_rx_n10   ), //           .rx_n_in10
            .hip_serial_rx_n_in11         (pcie_ep_rx_n11   ), //           .rx_n_in11
            .hip_serial_rx_n_in12         (pcie_ep_rx_n12   ), //           .rx_n_in12
            .hip_serial_rx_n_in13         (pcie_ep_rx_n13   ), //           .rx_n_in13
            .hip_serial_rx_n_in14         (pcie_ep_rx_n14   ), //           .rx_n_in14
            .hip_serial_rx_n_in15         (pcie_ep_rx_n15   ), //           .rx_n_in15
            .hip_serial_rx_p_in0          (pcie_ep_rx_p0    ), //           .rx_p_in0
            .hip_serial_rx_p_in1          (pcie_ep_rx_p1    ), //           .rx_p_in1
            .hip_serial_rx_p_in2          (pcie_ep_rx_p2    ), //           .rx_p_in2
            .hip_serial_rx_p_in3          (pcie_ep_rx_p3    ), //           .rx_p_in3
            .hip_serial_rx_p_in4          (pcie_ep_rx_p4    ), //           .rx_p_in4
            .hip_serial_rx_p_in5          (pcie_ep_rx_p5    ), //           .rx_p_in5
            .hip_serial_rx_p_in6          (pcie_ep_rx_p6    ), //           .rx_p_in6
            .hip_serial_rx_p_in7          (pcie_ep_rx_p7    ), //           .rx_p_in7
            .hip_serial_rx_p_in8          (pcie_ep_rx_p8    ), //           .rx_p_in8
            .hip_serial_rx_p_in9          (pcie_ep_rx_p9    ), //           .rx_p_in9
            .hip_serial_rx_p_in10         (pcie_ep_rx_p10   ), //           .rx_p_in10
            .hip_serial_rx_p_in11         (pcie_ep_rx_p11   ), //           .rx_p_in11
            .hip_serial_rx_p_in12         (pcie_ep_rx_p12   ), //           .rx_p_in12
            .hip_serial_rx_p_in13         (pcie_ep_rx_p13   ), //           .rx_p_in13
            .hip_serial_rx_p_in14         (pcie_ep_rx_p14   ), //           .rx_p_in14
            .hip_serial_rx_p_in15         (pcie_ep_rx_p15   ), //           .rx_p_in15
            .hip_serial_tx_n_out0         (pcie_ep_tx_n0    ), //           .tx_n_out0
            .hip_serial_tx_n_out1         (pcie_ep_tx_n1    ), //           .tx_n_out1
            .hip_serial_tx_n_out2         (pcie_ep_tx_n2    ), //           .tx_n_out2
            .hip_serial_tx_n_out3         (pcie_ep_tx_n3    ), //           .tx_n_out3
            .hip_serial_tx_n_out4         (pcie_ep_tx_n4    ), //           .tx_n_out4
            .hip_serial_tx_n_out5         (pcie_ep_tx_n5    ), //           .tx_n_out5
            .hip_serial_tx_n_out6         (pcie_ep_tx_n6    ), //           .tx_n_out6
            .hip_serial_tx_n_out7         (pcie_ep_tx_n7    ), //           .tx_n_out7
            .hip_serial_tx_n_out8         (pcie_ep_tx_n8    ), //           .tx_n_out8
            .hip_serial_tx_n_out9         (pcie_ep_tx_n9    ), //           .tx_n_out9
            .hip_serial_tx_n_out10        (pcie_ep_tx_n10   ), //           .tx_n_out10
            .hip_serial_tx_n_out11        (pcie_ep_tx_n11   ), //           .tx_n_out11
            .hip_serial_tx_n_out12        (pcie_ep_tx_n12   ), //           .tx_n_out12
            .hip_serial_tx_n_out13        (pcie_ep_tx_n13   ), //           .tx_n_out13
            .hip_serial_tx_n_out14        (pcie_ep_tx_n14   ), //           .tx_n_out14
            .hip_serial_tx_n_out15        (pcie_ep_tx_n15   ), //           .tx_n_out15
            .hip_serial_tx_p_out0         (pcie_ep_tx_p0    ), //           .tx_p_out0
            .hip_serial_tx_p_out1         (pcie_ep_tx_p1    ), //           .tx_p_out1
            .hip_serial_tx_p_out2         (pcie_ep_tx_p2    ), //           .tx_p_out2
            .hip_serial_tx_p_out3         (pcie_ep_tx_p3    ), //           .tx_p_out3
            .hip_serial_tx_p_out4         (pcie_ep_tx_p4    ), //           .tx_p_out4
            .hip_serial_tx_p_out5         (pcie_ep_tx_p5    ), //           .tx_p_out5
            .hip_serial_tx_p_out6         (pcie_ep_tx_p6    ), //           .tx_p_out6
            .hip_serial_tx_p_out7         (pcie_ep_tx_p7    ), //           .tx_p_out7
            .hip_serial_tx_p_out8         (pcie_ep_tx_p8    ), //           .tx_p_out8
            .hip_serial_tx_p_out9         (pcie_ep_tx_p9    ), //           .tx_p_out9
            .hip_serial_tx_p_out10        (pcie_ep_tx_p10   ), //           .tx_p_out10
            .hip_serial_tx_p_out11        (pcie_ep_tx_p11   ), //           .tx_p_out11
            .hip_serial_tx_p_out12        (pcie_ep_tx_p12   ), //           .tx_p_out12
            .hip_serial_tx_p_out13        (pcie_ep_tx_p13   ), //           .tx_p_out13
            .hip_serial_tx_p_out14        (pcie_ep_tx_p14   ), //           .tx_p_out14
            .hip_serial_tx_p_out15        (pcie_ep_tx_p15   )  //           .tx_p_out15
            );
endmodule
	