/*******************************************************************************
* Copyright (C) 2001-2025 Altera Corporation
*
* This code and the related documents are Altera copyrighted materials and
* your use of them is governed by the express license under which they were
* provided to you ("License"). Unless the License provides otherwise, you may
* not use, modify, copy, publish, distribute, disclose, or transmit this
* code or the related documents without Altera's prior written permission.
* 
* This code and the related documents are provided as is, with no express
* or implied warranties other than those that are expressly stated in the
* License.
* 
*******************************************************************************/


`timescale 1ns / 100ps
module  qsfpdd_xcvr (
        //Reset&Clock
        input  wire        cpu_resetn            , // Reset, low active
        input  wire        clk_sys_100m_p        , // System clock, 100MHz
        input  wire        clk_sys_bak_50m_p     , // System clock, 50MHz
        //I2C interfaces                         
        inout  wire        fpga_i2c_scl          , // FPGA regular I2C interface
        inout  wire        fpga_i2c_sda          , // FPGA regular I2C interface
        inout  wire        ddr4_dimm_scl         , // DDR4 I2C interface
        inout  wire        ddr4_dimm_sda         , // DDR4 I2C interface
        //GPIOs                                  
        output wire [3:0]  fm6_led               , // User LEDs
      //output wire        gpio_trig_out         , // GPIO trigger out, not available in EP version
      //input  wire        gpio_trig_in          , // GPIO trigger in, not available in EP version
        //XCVR reference clock
        input  wire        refclk_322m_qsfpdd_p  , // QSFPDD reference clock 322MHz
        input  wire        refclk_156m_qsfpdd_p  , // QSFPDD reference clock 156MHz
        //QSFPDD LEDs
        output wire [2:0]  qsfpdd0_fm6_led       , // QSFPDD0 LEDs
        output wire [2:0]  qsfpdd1_fm6_led       , // QSFPDD1 LEDs
        //QSFPDD control signals
        inout  wire        qsfpdd_fm6_i2c_scl    , // QSFPDD control
        inout  wire        qsfpdd_fm6_i2c_sda    , // QSFPDD control
        output wire        qsfpdd0_1v2_reset_l   , // QSFPDD control
        input  wire        qsfpdd0_1v2_modprs_l  , // QSFPDD control
        output wire        qsfpdd0_1v2_lpmode    , // QSFPDD control
        input  wire        qsfpdd0_1v2_int_l     , // QSFPDD control
        output wire        qsfpdd0_1v2_modsel_l  , // QSFPDD control
        output wire        qsfpdd1_1v2_reset_l   , // QSFPDD control
        input  wire        qsfpdd1_1v2_modprs_l  , // QSFPDD control
        output wire        qsfpdd1_1v2_modsel_l  , // QSFPDD control
        input  wire        qsfpdd1_1v2_int_l     , // QSFPDD control
        output wire        qsfpdd1_1v2_lpmode    , // QSFPDD control
        //QSFPDD XCVR channels
        input  wire [7:0]  qsfpdd0_rx_p          , // QSFPDD #0 RX P
        input  wire [7:0]  qsfpdd0_rx_n          , // QSFPDD #0 RX N
        output wire [7:0]  qsfpdd0_tx_p          , // QSFPDD #0 TX P
        output wire [7:0]  qsfpdd0_tx_n          , // QSFPDD #0 TX N
        input  wire [7:0]  qsfpdd1_rx_p          , // QSFPDD #1 RX P
        input  wire [7:0]  qsfpdd1_rx_n          , // QSFPDD #1 RX N
        output wire [7:0]  qsfpdd1_tx_p          , // QSFPDD #1 TX P
        output wire [7:0]  qsfpdd1_tx_n            // QSFPDD #1 TX N
        );
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//Signal definitions
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
wire          ninit_done/* synthesis keep */;
wire          global_resetn/* synthesis keep */;
reg  [26:0]   heart_beat_cnt/* synthesis keep */;
wire          fpga_i2c_scl_in/* synthesis keep */;
wire          fpga_i2c_sda_in/* synthesis keep */;
wire          fpga_i2c_scl_oe/* synthesis keep */;
wire          fpga_i2c_sda_oe/* synthesis keep */;
wire          ddr4_dimm_scl_in/* synthesis keep */;
wire          ddr4_dimm_sda_in/* synthesis keep */;
wire          ddr4_dimm_scl_oe/* synthesis keep */;
wire          ddr4_dimm_sda_oe/* synthesis keep */;
wire          qsfpdd_fm6_i2c_scl_in/* synthesis keep */;
wire          qsfpdd_fm6_i2c_sda_in/* synthesis keep */;
wire          qsfpdd_fm6_i2c_scl_oe/* synthesis keep */;
wire          qsfpdd_fm6_i2c_sda_oe/* synthesis keep */;
wire          qsfpdd_modsel_ctrl/* synthesis keep */;
wire          iopll_0_locked/* synthesis keep */;
wire          iopll_1_locked/* synthesis keep */;
wire          iopll_2_locked/* synthesis keep */;
wire          iopll_3_locked/* synthesis keep */;
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//Input/output assignments
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
assign fpga_i2c_scl_in       = fpga_i2c_scl;
assign fpga_i2c_sda_in       = fpga_i2c_sda;
assign fpga_i2c_scl          = fpga_i2c_scl_oe ? 1'b0 : 1'bz;
assign fpga_i2c_sda          = fpga_i2c_sda_oe ? 1'b0 : 1'bz;
assign ddr4_dimm_scl_in      = ddr4_dimm_scl;
assign ddr4_dimm_sda_in      = ddr4_dimm_sda;
assign ddr4_dimm_scl         = ddr4_dimm_scl_oe ? 1'b0 : 1'bz;
assign ddr4_dimm_sda         = ddr4_dimm_sda_oe ? 1'b0 : 1'bz;
assign qsfpdd_fm6_i2c_scl_in = qsfpdd_fm6_i2c_scl;
assign qsfpdd_fm6_i2c_sda_in = qsfpdd_fm6_i2c_sda;
assign qsfpdd_fm6_i2c_scl    = qsfpdd_fm6_i2c_scl_oe ? 1'b0 : 1'bz;
assign qsfpdd_fm6_i2c_sda    = qsfpdd_fm6_i2c_sda_oe ? 1'b0 : 1'bz;
assign fm6_led[0]            = iopll_0_locked & iopll_1_locked & iopll_2_locked & iopll_3_locked;
assign fm6_led[3:1]          = {heart_beat_cnt[26], heart_beat_cnt[26], heart_beat_cnt[26]};
//----------------------------------------------------------------------------------------------------------
// Intel Agilex Reset Release
//----------------------------------------------------------------------------------------------------------
reset_release reset_release_inst 
              (
              .ninit_done (ninit_done)  // ninit_done.ninit_done
              );
assign global_resetn = !ninit_done & cpu_resetn;
//assign global_resetn = cpu_resetn;
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//Heart-beat indicate
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
always @(posedge clk_sys_bak_50m_p or negedge global_resetn)
    if (!global_resetn)
        heart_beat_cnt <= 27'h0; //0x7FFFFFF
    else
        heart_beat_cnt <= heart_beat_cnt + 1'b1;
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//XCVR system Qsys module
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
q_sys   q_sys_u0 (
        .clk_100_clk                                                           (clk_sys_100m_p       ), //                                             clk_100.clk
        .reset_100_reset_n                                                     (global_resetn        ), //                                           reset_100.reset_n
        .clk_50_clk                                                            (clk_sys_bak_50m_p    ), //                                              clk_50.clk
        .reset_50_reset_n                                                      (global_resetn        ), //                                            reset_50.reset_n
        .i2c_0_i2c_serial_sda_in                                               (fpga_i2c_sda_in      ), //                                    i2c_0_i2c_serial.sda_in
        .i2c_0_i2c_serial_scl_in                                               (fpga_i2c_scl_in      ), //                                                    .scl_in
        .i2c_0_i2c_serial_sda_oe                                               (fpga_i2c_sda_oe      ), //                                                    .sda_oe
        .i2c_0_i2c_serial_scl_oe                                               (fpga_i2c_scl_oe      ), //                                                    .scl_oe
        .i2c_1_i2c_serial_sda_in                                               (ddr4_dimm_sda_in     ), //                                    i2c_1_i2c_serial.sda_in
        .i2c_1_i2c_serial_scl_in                                               (ddr4_dimm_scl_in     ), //                                                    .scl_in
        .i2c_1_i2c_serial_sda_oe                                               (ddr4_dimm_sda_oe     ), //                                                    .sda_oe
        .i2c_1_i2c_serial_scl_oe                                               (ddr4_dimm_scl_oe     ), //                                                    .scl_oe
        .i2c_2_i2c_serial_sda_in                                               (qsfpdd_fm6_i2c_sda_in), //                                    i2c_2_i2c_serial.sda_in
        .i2c_2_i2c_serial_scl_in                                               (qsfpdd_fm6_i2c_scl_in), //                                                    .scl_in
        .i2c_2_i2c_serial_sda_oe                                               (qsfpdd_fm6_i2c_sda_oe), //                                                    .sda_oe
        .i2c_2_i2c_serial_scl_oe                                               (qsfpdd_fm6_i2c_scl_oe), //                                                    .scl_oe
        .pio_2_external_connection_export                                      (qsfpdd_modsel_ctrl   ), // pio_0_external_connection.export
        .iopll_0_locked_export                                                 (iopll_0_locked       ), //                                      iopll_0_locked.export
        .iopll_1_locked_export                                                 (iopll_1_locked       ), //                                      iopll_1_locked.export
        .iopll_2_locked_export                                                 (iopll_2_locked       ), //                                      iopll_2_locked.export
        .iopll_3_locked_export                                                 (iopll_3_locked       ), //                                      iopll_3_locked.export
      //.module_debug_inputs_external_connection_export                        (                     ), //             module_debug_inputs_external_connection.export
      //.module_debug_outputs_external_connection_export                       (                     ), //            module_debug_outputs_external_connection.export
        .refclk_etile_9a_in_clk_clk                                            (refclk_156m_qsfpdd_p ), //                              refclk_etile_9a_in_clk.clk
      //.temp_info_0_fpga_core_temp_export                                     (                     ), //                          temp_info_0_fpga_core_temp.export
      //.temp_info_0_fpga_max_temp_export                                      (                     ), //                           temp_info_0_fpga_max_temp.export
      //.temp_info_0_fpga_xcvr_tile0_temp_export                               (                     ), //                    temp_info_0_fpga_xcvr_tile0_temp.export
      //.temp_info_0_fpga_xcvr_tile1_temp_export                               (                     ), //                    temp_info_0_fpga_xcvr_tile1_temp.export
      //.temp_info_0_fpga_xcvr_tile2_temp_export                               (                     ), //                    temp_info_0_fpga_xcvr_tile2_temp.export
      //.temp_info_0_fpga_xcvr_tile3_temp_export                               (                     ), //                    temp_info_0_fpga_xcvr_tile3_temp.export
      //.temp_info_0_fpga_xcvr_tile4_temp_export                               (                     ), //                    temp_info_0_fpga_xcvr_tile4_temp.export
      //.temp_info_0_fpga_xcvr_tile5_temp_export                               (                     ), //                    temp_info_0_fpga_xcvr_tile5_temp.export
        .qsfpdd0_xcvr_test_0_xcvrnphy_fme_0_reset_reset                        (!global_resetn       ), //            qsfpdd0_xcvr_test_0_xcvrnphy_fme_0_reset.reset
        .qsfpdd0_xcvr_test_0_xcvrnphy_fme_0_tx_serial_data_tx_serial_data      (qsfpdd0_tx_p[0]      ), //   qsfpdd0_xcvr_test_0_xcvrnphy_fme_0_tx_serial_data.tx_serial_data
        .qsfpdd0_xcvr_test_0_xcvrnphy_fme_0_tx_serial_data_n_tx_serial_data_n  (qsfpdd0_tx_n[0]      ), // qsfpdd0_xcvr_test_0_xcvrnphy_fme_0_tx_serial_data_n.tx_serial_data_n
        .qsfpdd0_xcvr_test_0_xcvrnphy_fme_0_rx_serial_data_rx_serial_data      (qsfpdd0_rx_p[0]      ), //   qsfpdd0_xcvr_test_0_xcvrnphy_fme_0_rx_serial_data.rx_serial_data
        .qsfpdd0_xcvr_test_0_xcvrnphy_fme_0_rx_serial_data_n_rx_serial_data_n  (qsfpdd0_rx_n[0]      ), // qsfpdd0_xcvr_test_0_xcvrnphy_fme_0_rx_serial_data_n.rx_serial_data_n
        .qsfpdd0_xcvr_test_1_xcvrnphy_fme_0_reset_reset                        (!global_resetn       ), //            qsfpdd0_xcvr_test_1_xcvrnphy_fme_0_reset.reset
        .qsfpdd0_xcvr_test_1_xcvrnphy_fme_0_tx_serial_data_tx_serial_data      (qsfpdd0_tx_p[2]      ), //   qsfpdd0_xcvr_test_1_xcvrnphy_fme_0_tx_serial_data.tx_serial_data
        .qsfpdd0_xcvr_test_1_xcvrnphy_fme_0_tx_serial_data_n_tx_serial_data_n  (qsfpdd0_tx_n[2]      ), // qsfpdd0_xcvr_test_1_xcvrnphy_fme_0_tx_serial_data_n.tx_serial_data_n
        .qsfpdd0_xcvr_test_1_xcvrnphy_fme_0_rx_serial_data_rx_serial_data      (qsfpdd0_rx_p[2]      ), //   qsfpdd0_xcvr_test_1_xcvrnphy_fme_0_rx_serial_data.rx_serial_data
        .qsfpdd0_xcvr_test_1_xcvrnphy_fme_0_rx_serial_data_n_rx_serial_data_n  (qsfpdd0_rx_n[2]      ), // qsfpdd0_xcvr_test_1_xcvrnphy_fme_0_rx_serial_data_n.rx_serial_data_n
        .qsfpdd0_xcvr_test_2_xcvrnphy_fme_0_reset_reset                        (!global_resetn       ), //            qsfpdd0_xcvr_test_2_xcvrnphy_fme_0_reset.reset
        .qsfpdd0_xcvr_test_2_xcvrnphy_fme_0_tx_serial_data_tx_serial_data      (qsfpdd0_tx_p[1]      ), //   qsfpdd0_xcvr_test_2_xcvrnphy_fme_0_tx_serial_data.tx_serial_data
        .qsfpdd0_xcvr_test_2_xcvrnphy_fme_0_tx_serial_data_n_tx_serial_data_n  (qsfpdd0_tx_n[1]      ), // qsfpdd0_xcvr_test_2_xcvrnphy_fme_0_tx_serial_data_n.tx_serial_data_n
        .qsfpdd0_xcvr_test_2_xcvrnphy_fme_0_rx_serial_data_rx_serial_data      (qsfpdd0_rx_p[1]      ), //   qsfpdd0_xcvr_test_2_xcvrnphy_fme_0_rx_serial_data.rx_serial_data
        .qsfpdd0_xcvr_test_2_xcvrnphy_fme_0_rx_serial_data_n_rx_serial_data_n  (qsfpdd0_rx_n[1]      ), // qsfpdd0_xcvr_test_2_xcvrnphy_fme_0_rx_serial_data_n.rx_serial_data_n
        .qsfpdd0_xcvr_test_3_xcvrnphy_fme_0_reset_reset                        (!global_resetn       ), //            qsfpdd0_xcvr_test_3_xcvrnphy_fme_0_reset.reset
        .qsfpdd0_xcvr_test_3_xcvrnphy_fme_0_tx_serial_data_tx_serial_data      (qsfpdd0_tx_p[3]      ), //   qsfpdd0_xcvr_test_3_xcvrnphy_fme_0_tx_serial_data.tx_serial_data
        .qsfpdd0_xcvr_test_3_xcvrnphy_fme_0_tx_serial_data_n_tx_serial_data_n  (qsfpdd0_tx_n[3]      ), // qsfpdd0_xcvr_test_3_xcvrnphy_fme_0_tx_serial_data_n.tx_serial_data_n
        .qsfpdd0_xcvr_test_3_xcvrnphy_fme_0_rx_serial_data_rx_serial_data      (qsfpdd0_rx_p[3]      ), //   qsfpdd0_xcvr_test_3_xcvrnphy_fme_0_rx_serial_data.rx_serial_data
        .qsfpdd0_xcvr_test_3_xcvrnphy_fme_0_rx_serial_data_n_rx_serial_data_n  (qsfpdd0_rx_n[3]      ), // qsfpdd0_xcvr_test_3_xcvrnphy_fme_0_rx_serial_data_n.rx_serial_data_n
        .qsfpdd0_xcvr_test_4_xcvrnphy_fme_0_reset_reset                        (!global_resetn       ), //            qsfpdd0_xcvr_test_4_xcvrnphy_fme_0_reset.reset
        .qsfpdd0_xcvr_test_4_xcvrnphy_fme_0_tx_serial_data_tx_serial_data      (qsfpdd0_tx_p[4]      ), //   qsfpdd0_xcvr_test_4_xcvrnphy_fme_0_tx_serial_data.tx_serial_data
        .qsfpdd0_xcvr_test_4_xcvrnphy_fme_0_tx_serial_data_n_tx_serial_data_n  (qsfpdd0_tx_n[4]      ), // qsfpdd0_xcvr_test_4_xcvrnphy_fme_0_tx_serial_data_n.tx_serial_data_n
        .qsfpdd0_xcvr_test_4_xcvrnphy_fme_0_rx_serial_data_rx_serial_data      (qsfpdd0_rx_p[4]      ), //   qsfpdd0_xcvr_test_4_xcvrnphy_fme_0_rx_serial_data.rx_serial_data
        .qsfpdd0_xcvr_test_4_xcvrnphy_fme_0_rx_serial_data_n_rx_serial_data_n  (qsfpdd0_rx_n[4]      ), // qsfpdd0_xcvr_test_4_xcvrnphy_fme_0_rx_serial_data_n.rx_serial_data_n
        .qsfpdd0_xcvr_test_5_xcvrnphy_fme_0_reset_reset                        (!global_resetn       ), //            qsfpdd0_xcvr_test_5_xcvrnphy_fme_0_reset.reset
        .qsfpdd0_xcvr_test_5_xcvrnphy_fme_0_tx_serial_data_tx_serial_data      (qsfpdd0_tx_p[6]      ), //   qsfpdd0_xcvr_test_5_xcvrnphy_fme_0_tx_serial_data.tx_serial_data
        .qsfpdd0_xcvr_test_5_xcvrnphy_fme_0_tx_serial_data_n_tx_serial_data_n  (qsfpdd0_tx_n[6]      ), // qsfpdd0_xcvr_test_5_xcvrnphy_fme_0_tx_serial_data_n.tx_serial_data_n
        .qsfpdd0_xcvr_test_5_xcvrnphy_fme_0_rx_serial_data_rx_serial_data      (qsfpdd0_rx_p[6]      ), //   qsfpdd0_xcvr_test_5_xcvrnphy_fme_0_rx_serial_data.rx_serial_data
        .qsfpdd0_xcvr_test_5_xcvrnphy_fme_0_rx_serial_data_n_rx_serial_data_n  (qsfpdd0_rx_n[6]      ), // qsfpdd0_xcvr_test_5_xcvrnphy_fme_0_rx_serial_data_n.rx_serial_data_n
        .qsfpdd0_xcvr_test_6_xcvrnphy_fme_0_reset_reset                        (!global_resetn       ), //            qsfpdd0_xcvr_test_6_xcvrnphy_fme_0_reset.reset
        .qsfpdd0_xcvr_test_6_xcvrnphy_fme_0_tx_serial_data_tx_serial_data      (qsfpdd0_tx_p[5]      ), //   qsfpdd0_xcvr_test_6_xcvrnphy_fme_0_tx_serial_data.tx_serial_data
        .qsfpdd0_xcvr_test_6_xcvrnphy_fme_0_tx_serial_data_n_tx_serial_data_n  (qsfpdd0_tx_n[5]      ), // qsfpdd0_xcvr_test_6_xcvrnphy_fme_0_tx_serial_data_n.tx_serial_data_n
        .qsfpdd0_xcvr_test_6_xcvrnphy_fme_0_rx_serial_data_rx_serial_data      (qsfpdd0_rx_p[5]      ), //   qsfpdd0_xcvr_test_6_xcvrnphy_fme_0_rx_serial_data.rx_serial_data
        .qsfpdd0_xcvr_test_6_xcvrnphy_fme_0_rx_serial_data_n_rx_serial_data_n  (qsfpdd0_rx_n[5]      ), // qsfpdd0_xcvr_test_6_xcvrnphy_fme_0_rx_serial_data_n.rx_serial_data_n
        .qsfpdd0_xcvr_test_7_xcvrnphy_fme_0_reset_reset                        (!global_resetn       ), //            qsfpdd0_xcvr_test_7_xcvrnphy_fme_0_reset.reset
        .qsfpdd0_xcvr_test_7_xcvrnphy_fme_0_tx_serial_data_tx_serial_data      (qsfpdd0_tx_p[7]      ), //   qsfpdd0_xcvr_test_7_xcvrnphy_fme_0_tx_serial_data.tx_serial_data
        .qsfpdd0_xcvr_test_7_xcvrnphy_fme_0_tx_serial_data_n_tx_serial_data_n  (qsfpdd0_tx_n[7]      ), // qsfpdd0_xcvr_test_7_xcvrnphy_fme_0_tx_serial_data_n.tx_serial_data_n
        .qsfpdd0_xcvr_test_7_xcvrnphy_fme_0_rx_serial_data_rx_serial_data      (qsfpdd0_rx_p[7]      ), //   qsfpdd0_xcvr_test_7_xcvrnphy_fme_0_rx_serial_data.rx_serial_data
        .qsfpdd0_xcvr_test_7_xcvrnphy_fme_0_rx_serial_data_n_rx_serial_data_n  (qsfpdd0_rx_n[7]      ), // qsfpdd0_xcvr_test_7_xcvrnphy_fme_0_rx_serial_data_n.rx_serial_data_n
        .qsfpdd1_xcvr_test_0_xcvrnphy_fme_0_reset_reset                        (!global_resetn       ), //            qsfpdd1_xcvr_test_0_xcvrnphy_fme_0_reset.reset
        .qsfpdd1_xcvr_test_0_xcvrnphy_fme_0_tx_serial_data_tx_serial_data      (qsfpdd1_tx_p[0]      ), //   qsfpdd1_xcvr_test_0_xcvrnphy_fme_0_tx_serial_data.tx_serial_data
        .qsfpdd1_xcvr_test_0_xcvrnphy_fme_0_tx_serial_data_n_tx_serial_data_n  (qsfpdd1_tx_n[0]      ), // qsfpdd1_xcvr_test_0_xcvrnphy_fme_0_tx_serial_data_n.tx_serial_data_n
        .qsfpdd1_xcvr_test_0_xcvrnphy_fme_0_rx_serial_data_rx_serial_data      (qsfpdd1_rx_p[0]      ), //   qsfpdd1_xcvr_test_0_xcvrnphy_fme_0_rx_serial_data.rx_serial_data
        .qsfpdd1_xcvr_test_0_xcvrnphy_fme_0_rx_serial_data_n_rx_serial_data_n  (qsfpdd1_rx_n[0]      ), // qsfpdd1_xcvr_test_0_xcvrnphy_fme_0_rx_serial_data_n.rx_serial_data_n
        .qsfpdd1_xcvr_test_1_xcvrnphy_fme_0_reset_reset                        (!global_resetn       ), //            qsfpdd1_xcvr_test_1_xcvrnphy_fme_0_reset.reset
        .qsfpdd1_xcvr_test_1_xcvrnphy_fme_0_tx_serial_data_tx_serial_data      (qsfpdd1_tx_p[2]      ), //   qsfpdd1_xcvr_test_1_xcvrnphy_fme_0_tx_serial_data.tx_serial_data
        .qsfpdd1_xcvr_test_1_xcvrnphy_fme_0_tx_serial_data_n_tx_serial_data_n  (qsfpdd1_tx_n[2]      ), // qsfpdd1_xcvr_test_1_xcvrnphy_fme_0_tx_serial_data_n.tx_serial_data_n
        .qsfpdd1_xcvr_test_1_xcvrnphy_fme_0_rx_serial_data_rx_serial_data      (qsfpdd1_rx_p[2]      ), //   qsfpdd1_xcvr_test_1_xcvrnphy_fme_0_rx_serial_data.rx_serial_data
        .qsfpdd1_xcvr_test_1_xcvrnphy_fme_0_rx_serial_data_n_rx_serial_data_n  (qsfpdd1_rx_n[2]      ), // qsfpdd1_xcvr_test_1_xcvrnphy_fme_0_rx_serial_data_n.rx_serial_data_n
        .qsfpdd1_xcvr_test_2_xcvrnphy_fme_0_reset_reset                        (!global_resetn       ), //            qsfpdd1_xcvr_test_2_xcvrnphy_fme_0_reset.reset
        .qsfpdd1_xcvr_test_2_xcvrnphy_fme_0_tx_serial_data_tx_serial_data      (qsfpdd1_tx_p[1]      ), //   qsfpdd1_xcvr_test_2_xcvrnphy_fme_0_tx_serial_data.tx_serial_data
        .qsfpdd1_xcvr_test_2_xcvrnphy_fme_0_tx_serial_data_n_tx_serial_data_n  (qsfpdd1_tx_n[1]      ), // qsfpdd1_xcvr_test_2_xcvrnphy_fme_0_tx_serial_data_n.tx_serial_data_n
        .qsfpdd1_xcvr_test_2_xcvrnphy_fme_0_rx_serial_data_rx_serial_data      (qsfpdd1_rx_p[1]      ), //   qsfpdd1_xcvr_test_2_xcvrnphy_fme_0_rx_serial_data.rx_serial_data
        .qsfpdd1_xcvr_test_2_xcvrnphy_fme_0_rx_serial_data_n_rx_serial_data_n  (qsfpdd1_rx_n[1]      ), // qsfpdd1_xcvr_test_2_xcvrnphy_fme_0_rx_serial_data_n.rx_serial_data_n
        .qsfpdd1_xcvr_test_3_xcvrnphy_fme_0_reset_reset                        (!global_resetn       ), //            qsfpdd1_xcvr_test_3_xcvrnphy_fme_0_reset.reset
        .qsfpdd1_xcvr_test_3_xcvrnphy_fme_0_tx_serial_data_tx_serial_data      (qsfpdd1_tx_p[3]      ), //   qsfpdd1_xcvr_test_3_xcvrnphy_fme_0_tx_serial_data.tx_serial_data
        .qsfpdd1_xcvr_test_3_xcvrnphy_fme_0_tx_serial_data_n_tx_serial_data_n  (qsfpdd1_tx_n[3]      ), // qsfpdd1_xcvr_test_3_xcvrnphy_fme_0_tx_serial_data_n.tx_serial_data_n
        .qsfpdd1_xcvr_test_3_xcvrnphy_fme_0_rx_serial_data_rx_serial_data      (qsfpdd1_rx_p[3]      ), //   qsfpdd1_xcvr_test_3_xcvrnphy_fme_0_rx_serial_data.rx_serial_data
        .qsfpdd1_xcvr_test_3_xcvrnphy_fme_0_rx_serial_data_n_rx_serial_data_n  (qsfpdd1_rx_n[3]      ), // qsfpdd1_xcvr_test_3_xcvrnphy_fme_0_rx_serial_data_n.rx_serial_data_n
        .qsfpdd1_xcvr_test_4_xcvrnphy_fme_0_reset_reset                        (!global_resetn       ), //            qsfpdd1_xcvr_test_4_xcvrnphy_fme_0_reset.reset
        .qsfpdd1_xcvr_test_4_xcvrnphy_fme_0_tx_serial_data_tx_serial_data      (qsfpdd1_tx_p[4]      ), //   qsfpdd1_xcvr_test_4_xcvrnphy_fme_0_tx_serial_data.tx_serial_data
        .qsfpdd1_xcvr_test_4_xcvrnphy_fme_0_tx_serial_data_n_tx_serial_data_n  (qsfpdd1_tx_n[4]      ), // qsfpdd1_xcvr_test_4_xcvrnphy_fme_0_tx_serial_data_n.tx_serial_data_n
        .qsfpdd1_xcvr_test_4_xcvrnphy_fme_0_rx_serial_data_rx_serial_data      (qsfpdd1_rx_p[4]      ), //   qsfpdd1_xcvr_test_4_xcvrnphy_fme_0_rx_serial_data.rx_serial_data
        .qsfpdd1_xcvr_test_4_xcvrnphy_fme_0_rx_serial_data_n_rx_serial_data_n  (qsfpdd1_rx_n[4]      ), // qsfpdd1_xcvr_test_4_xcvrnphy_fme_0_rx_serial_data_n.rx_serial_data_n
        .qsfpdd1_xcvr_test_5_xcvrnphy_fme_0_reset_reset                        (!global_resetn       ), //            qsfpdd1_xcvr_test_5_xcvrnphy_fme_0_reset.reset
        .qsfpdd1_xcvr_test_5_xcvrnphy_fme_0_tx_serial_data_tx_serial_data      (qsfpdd1_tx_p[6]      ), //   qsfpdd1_xcvr_test_5_xcvrnphy_fme_0_tx_serial_data.tx_serial_data
        .qsfpdd1_xcvr_test_5_xcvrnphy_fme_0_tx_serial_data_n_tx_serial_data_n  (qsfpdd1_tx_n[6]      ), // qsfpdd1_xcvr_test_5_xcvrnphy_fme_0_tx_serial_data_n.tx_serial_data_n
        .qsfpdd1_xcvr_test_5_xcvrnphy_fme_0_rx_serial_data_rx_serial_data      (qsfpdd1_rx_p[6]      ), //   qsfpdd1_xcvr_test_5_xcvrnphy_fme_0_rx_serial_data.rx_serial_data
        .qsfpdd1_xcvr_test_5_xcvrnphy_fme_0_rx_serial_data_n_rx_serial_data_n  (qsfpdd1_rx_n[6]      ), // qsfpdd1_xcvr_test_5_xcvrnphy_fme_0_rx_serial_data_n.rx_serial_data_n
        .qsfpdd1_xcvr_test_6_xcvrnphy_fme_0_reset_reset                        (!global_resetn       ), //            qsfpdd1_xcvr_test_6_xcvrnphy_fme_0_reset.reset
        .qsfpdd1_xcvr_test_6_xcvrnphy_fme_0_tx_serial_data_tx_serial_data      (qsfpdd1_tx_p[5]      ), //   qsfpdd1_xcvr_test_6_xcvrnphy_fme_0_tx_serial_data.tx_serial_data
        .qsfpdd1_xcvr_test_6_xcvrnphy_fme_0_tx_serial_data_n_tx_serial_data_n  (qsfpdd1_tx_n[5]      ), // qsfpdd1_xcvr_test_6_xcvrnphy_fme_0_tx_serial_data_n.tx_serial_data_n
        .qsfpdd1_xcvr_test_6_xcvrnphy_fme_0_rx_serial_data_rx_serial_data      (qsfpdd1_rx_p[5]      ), //   qsfpdd1_xcvr_test_6_xcvrnphy_fme_0_rx_serial_data.rx_serial_data
        .qsfpdd1_xcvr_test_6_xcvrnphy_fme_0_rx_serial_data_n_rx_serial_data_n  (qsfpdd1_rx_n[5]      ), // qsfpdd1_xcvr_test_6_xcvrnphy_fme_0_rx_serial_data_n.rx_serial_data_n
        .qsfpdd1_xcvr_test_7_xcvrnphy_fme_0_reset_reset                        (!global_resetn       ), //            qsfpdd1_xcvr_test_7_xcvrnphy_fme_0_reset.reset
        .qsfpdd1_xcvr_test_7_xcvrnphy_fme_0_tx_serial_data_tx_serial_data      (qsfpdd1_tx_p[7]      ), //   qsfpdd1_xcvr_test_7_xcvrnphy_fme_0_tx_serial_data.tx_serial_data
        .qsfpdd1_xcvr_test_7_xcvrnphy_fme_0_tx_serial_data_n_tx_serial_data_n  (qsfpdd1_tx_n[7]      ), // qsfpdd1_xcvr_test_7_xcvrnphy_fme_0_tx_serial_data_n.tx_serial_data_n
        .qsfpdd1_xcvr_test_7_xcvrnphy_fme_0_rx_serial_data_rx_serial_data      (qsfpdd1_rx_p[7]      ), //   qsfpdd1_xcvr_test_7_xcvrnphy_fme_0_rx_serial_data.rx_serial_data
        .qsfpdd1_xcvr_test_7_xcvrnphy_fme_0_rx_serial_data_n_rx_serial_data_n  (qsfpdd1_rx_n[7]      )  // qsfpdd1_xcvr_test_7_xcvrnphy_fme_0_rx_serial_data_n.rx_serial_data_n
        );
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
assign qsfpdd0_fm6_led      = 3'bzzz; // Only for debug, external pull-up
assign qsfpdd1_fm6_led      = 3'bzzz; // Only for debug, external pull-up
assign qsfpdd0_1v2_reset_l  = 1'bz;                             // Only for debug, external pull-up
assign qsfpdd0_1v2_modsel_l = qsfpdd_modsel_ctrl ? 1'bz : 1'b0; // Only for debug, external pull-up
assign qsfpdd0_1v2_lpmode   = 1'b0;                             // Only for debug
assign qsfpdd1_1v2_reset_l  = 1'bz;                             // Only for debug, external pull-up
assign qsfpdd1_1v2_modsel_l = qsfpdd_modsel_ctrl ? 1'b0 : 1'bz; // Only for debug, external pull-up
assign qsfpdd1_1v2_lpmode   = 1'b0;                             // Only for debug
endmodule
	