// (C) 2001-2024 Intel Corporation. All rights reserved.
// Your use of Intel Corporation's design tools, logic functions and other 
// software and tools, and its AMPP partner logic functions, and any output 
// files from any of the foregoing (including device programming or simulation 
// files), and any associated documentation or information are expressly subject 
// to the terms and conditions of the Intel Program License Subscription 
// Agreement, Intel FPGA IP License Agreement, or other applicable 
// license agreement, including, without limitation, that your use is for the 
// sole purpose of programming logic devices manufactured by Intel and sold by 
// Intel or its authorized distributors.  Please refer to the applicable 
// agreement for further details.


`timescale 1 ps / 1 ps
module  ddr4 (
        //Reset&Clock
        input  wire        cpu_resetn            , // Reset, low active
        input  wire        clk_sys_100m_p        , // System clock, 100MHz
        input  wire        clk_sys_bak_50m_p     , // System clock, 50MHz
        input  wire        refclk_156m_qsfpdd_p  , // QSFPDD reference clock 156.25MHz
      //input  wire        refclk_pcie_ch0_p     , // PCIe reference clock 100MHz
        //I2C interfaces                         
        inout  wire        fpga_i2c_scl          , // FPGA regular I2C interface
        inout  wire        fpga_i2c_sda          , // FPGA regular I2C interface
        inout  wire        ddr4_dimm_scl         , // DDR4 I2C interface
        inout  wire        ddr4_dimm_sda         , // DDR4 I2C interface
        //GPIOs                                  
        output wire [3:0]  fm6_led               , // User LEDs
      //output wire        gpio_trig_out         , // GPIO trigger out, not available in EP version
      //input  wire        gpio_trig_in          , // GPIO trigger in, not available in EP version
        //EMIF interface
        input  wire        clk_ddr4_ch2_p        , // ddr_ref_clk.clk
      //output wire [1:0]  ddr4_dimm_ch2_ck_p    , //         mem.mem_ck
      //output wire [1:0]  ddr4_dimm_ch2_ck_n    , //            .mem_ck_n
        output wire        ddr4_dimm_ch2_ck_p_0  , //         mem.mem_ck
        output wire        ddr4_dimm_ch2_ck_n_0  , //            .mem_ck_n
      //output wire [17:0] ddr4_dimm_ch2_a       , //            .mem_a
        output wire [16:0] ddr4_dimm_ch2_a       , //            .mem_a
        output wire        ddr4_dimm_ch2_act_n   , //            .mem_act_n
        output wire [1:0]  ddr4_dimm_ch2_ba      , //            .mem_ba
        output wire [1:0]  ddr4_dimm_ch2_bg      , //            .mem_bg
      //output wire [1:0]  ddr4_dimm_ch2_cke     , //            .mem_cke
      //output wire [3:0]  ddr4_dimm_ch2_cs_n    , //            .mem_cs_n
      //output wire [1:0]  ddr4_dimm_ch2_odt     , //            .mem_odt
        output wire        ddr4_dimm_ch2_cke_0   , //            .mem_cke
        output wire        ddr4_dimm_ch2_cs_n_0  , //            .mem_cs_n
        output wire        ddr4_dimm_ch2_odt_0   , //            .mem_odt
        output wire        ddr4_dimm_ch2_reset_n , //            .mem_reset_n
        output wire        ddr4_dimm_ch2_par     , //            .mem_par
        input  wire        ddr4_dimm_ch2_alert_n , //            .mem_alert_n
        inout  wire [8:0]  ddr4_dimm_ch2_dqs_p   , //            .mem_dqs
        inout  wire [8:0]  ddr4_dimm_ch2_dqs_n   , //            .mem_dqs_n
        inout  wire [8:0]  ddr4_dimm_ch2_dbi_n   , //            .mem_dqs
      //inout  wire [17:9] ddr4_dimm_ch2_tdqs_n  , //            .mem_tdqs_n
      //inout  wire        ddr4_ch2_save_n       , //            .mem_save_n
      //inout  wire        ddr4_ch2_event_n      , //            .mem_event_n
      //inout  wire        ddr4_dimm_ch2_c2      , //            .unused
        inout  wire [71:0] ddr4_dimm_ch2_dq      , //            .mem_dq
        input  wire        ddr4_dimm_ch2_rzq       //            .oct_rzqin        
        );
//----------------------------------------------------------------------------------------------------------
// Singal definitions
//----------------------------------------------------------------------------------------------------------
wire           ninit_done;
wire           global_resetn/* synthesis keep */;
reg     [26:0] heart_beat_cnt;
wire    [2:0]  test_status/* synthesis keep */;
//----------------------------------------------------------------------------------------------------------
// Intel Agilex Reset Release
//----------------------------------------------------------------------------------------------------------
reset_release reset_release_inst 
              (
              .ninit_done (ninit_done)  // ninit_done.ninit_done
              );
assign global_resetn = !ninit_done & cpu_resetn;
//assign global_resetn = cpu_resetn;
//----------------------------------------------------------------------------------------------------------
// Glue logic for heart beat
//----------------------------------------------------------------------------------------------------------
always @(posedge clk_sys_bak_50m_p or negedge global_resetn)
        if (!global_resetn)
            heart_beat_cnt <= 27'h0; //0x7FFFFFF
        else
            heart_beat_cnt <= heart_beat_cnt + 1'b1;
//----------------------------------------------------------------------------------------------------------
// DDR4 example design
//----------------------------------------------------------------------------------------------------------
ed_synth    ed_synth_u0 (
            .clk_50m_clk                              (clk_sys_bak_50m_p    ), //                           clk_50m.clk
            .global_reset_reset_n                     (global_resetn        ), //                      global_reset.reset_n
          //.clock_bridge_100mhz_clk                  (clk_sys_100m_p       ), //               clock_bridge_100mhz.clk
          //.reset_bridge_100mhz_reset_n              (global_resetn        ), //               reset_bridge_100mhz.reset_n
            .clock_bridge_emif_refclk_clk             (clk_ddr4_ch2_p       ), //          clock_bridge_emif_refclk.clk
            .emif_fm_0_oct_oct_rzqin                  (ddr4_dimm_ch2_rzq    ), //                     emif_fm_0_oct.oct_rzqin
            .emif_fm_0_mem_mem_ck                     (ddr4_dimm_ch2_ck_p_0 ), //                     emif_fm_0_mem.mem_ck
            .emif_fm_0_mem_mem_ck_n                   (ddr4_dimm_ch2_ck_n_0 ), //                                  .mem_ck_n
            .emif_fm_0_mem_mem_a                      (ddr4_dimm_ch2_a      ), //                                  .mem_a
            .emif_fm_0_mem_mem_act_n                  (ddr4_dimm_ch2_act_n  ), //                                  .mem_act_n
            .emif_fm_0_mem_mem_ba                     (ddr4_dimm_ch2_ba     ), //                                  .mem_ba
            .emif_fm_0_mem_mem_bg                     (ddr4_dimm_ch2_bg     ), //                                  .mem_bg
            .emif_fm_0_mem_mem_cke                    (ddr4_dimm_ch2_cke_0  ), //                                  .mem_cke
            .emif_fm_0_mem_mem_cs_n                   (ddr4_dimm_ch2_cs_n_0 ), //                                  .mem_cs_n
            .emif_fm_0_mem_mem_odt                    (ddr4_dimm_ch2_odt_0  ), //                                  .mem_odt
            .emif_fm_0_mem_mem_reset_n                (ddr4_dimm_ch2_reset_n), //                                  .mem_reset_n
            .emif_fm_0_mem_mem_par                    (ddr4_dimm_ch2_par    ), //                                  .mem_par
            .emif_fm_0_mem_mem_alert_n                (ddr4_dimm_ch2_alert_n), //                                  .mem_alert_n
            .emif_fm_0_mem_mem_dqs                    (ddr4_dimm_ch2_dqs_p  ), //                                  .mem_dqs
            .emif_fm_0_mem_mem_dqs_n                  (ddr4_dimm_ch2_dqs_n  ), //                                  .mem_dqs_n
            .emif_fm_0_mem_mem_dq                     (ddr4_dimm_ch2_dq     ), //                                  .mem_dq
            .emif_fm_0_mem_mem_dbi_n                  (ddr4_dimm_ch2_dbi_n  ), //                                  .mem_dbi_n
            .local_reset_req                          (global_resetn        ), //                   local_reset_req.local_reset_req
            .local_reset_done                         (test_status[2]       ), //                local_reset_status.local_reset_done
            .master_driver_msgdma_0_error_mon_export  (test_status[1]       ), //  master_driver_msgdma_0_error_mon.export
            .master_driver_msgdma_0_status_mon_export (test_status[0]       )  // master_driver_msgdma_0_status_mon.export
            );
//----------------------------------------------------------------------------------------------------------
// Output assignments control
//----------------------------------------------------------------------------------------------------------
assign fm6_led[3:0]  = {heart_beat_cnt[26],test_status[2], test_status[1], test_status[0]};
assign fpga_i2c_scl  = 1'bz;
assign fpga_i2c_sda  = 1'bz;
assign ddr4_dimm_scl = 1'bz;
assign ddr4_dimm_sda = 1'bz;
endmodule
