/*******************************************************************************
* Copyright (C) 2001-2025 Altera Corporation
*
* This code and the related documents are Altera copyrighted materials and
* your use of them is governed by the express license under which they were
* provided to you ("License"). Unless the License provides otherwise, you may
* not use, modify, copy, publish, distribute, disclose, or transmit this
* code or the related documents without Altera's prior written permission.
* 
* This code and the related documents are provided as is, with no express
* or implied warranties other than those that are expressly stated in the
* License.
* 
*******************************************************************************/


// synthesis translate_off
`timescale 1ns / 1ps
// synthesis translate_on
// turn off superfluous verilog processor warnings 
// altera message_level Level1 
// altera message_off 10034 10035 10036 10037 10230 10240 10030 
module reset_gen(
	input	reset_n,
	input	clk,
	
	input		[3:0]	csr_address,
	input				csr_read,
	input				csr_write,
	output reg[31:0]csr_readdata,
	input		[31:0]csr_writedata,
	output			csr_waitrequest,
	output reset_out
);
	reg issue_reset, issue_reset_int1, issue_reset_int2;
	reg reset_out_int;
	reg [3:0] counter;
	assign reset_out = issue_reset;
	
	reg irq_int1, irq_int2, irq_int;
	// counter for self clear bit
	always @ (posedge clk or negedge reset_n)begin
		if (reset_n == 0)begin
			counter <= 15;
		end else begin
			if(csr_write == 1 & csr_address == 3'b000 & csr_writedata[0] == 1)begin
				counter <= 0;
			end else if(counter == 15)begin
				counter <= counter;
			end else begin
				counter <= counter + 1;
			end
		end
	end
	
	// generating issue_reset command
	always @ (posedge clk or negedge reset_n)begin
		if (reset_n == 0)begin
			issue_reset_int1 <= 0;
		end else if(counter == 15)begin // self clear
			issue_reset_int1 <= 0;
		end else if (counter == 1)begin
			issue_reset_int1 <= 1;
		end
	end
	always @ (posedge clk or negedge reset_n)begin
		if (reset_n == 0)begin
			issue_reset <= 0;
			issue_reset_int2 <= 1;
		end else  begin
			issue_reset <= issue_reset_int1 & issue_reset_int2;
			issue_reset_int2 <= !issue_reset_int1;
		end
	end
	
endmodule
